"use strict";
// Copyright IBM Corp. 2020. All Rights Reserved.
// Node module: @loopback/example-multi-tenancy
// This file is licensed under the MIT License.
// License text available at https://opensource.org/licenses/MIT
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWTStrategy = void 0;
const tslib_1 = require("tslib");
const debug_1 = (0, tslib_1.__importDefault)(require("debug"));
const jsonwebtoken_1 = require("jsonwebtoken");
const base_strategy_1 = require("./base-strategy");
const debug = (0, debug_1.default)('loopback:multi-tenancy:strategy:jwt');
/**
 * Use jwt token to identify the tenant id
 */
class JWTStrategy extends base_strategy_1.BaseStrategy {
    constructor() {
        super(...arguments);
        this.name = 'jwt';
    }
    identifyTenant(requestContext) {
        const authorization = requestContext.request.headers['authorization'];
        debug('authorization', authorization);
        if (authorization === null || authorization === void 0 ? void 0 : authorization.startsWith('Bearer ')) {
            //split the string into 2 parts : 'Bearer ' and the `xxx.yyy.zzz`
            const parts = authorization.split(' ');
            const token = parts[1];
            debug('JWT token', authorization);
            const json = (0, jsonwebtoken_1.decode)(token, { json: true });
            debug('Token', json);
            const tenantId = json === null || json === void 0 ? void 0 : json.tenantId;
            debug('Tenant id', tenantId);
            return tenantId == null ? undefined : { id: tenantId };
        }
    }
}
exports.JWTStrategy = JWTStrategy;
//# sourceMappingURL=jwt-strategy.js.map